@@ -16,13 +16,23 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <QtCore/QDir>
+
 #include "statictimezonemodel.h"
 
 StaticTimeZoneModel::StaticTimeZoneModel(QObject *parent) :
     TimeZoneModel(parent)
 {
     setlocale(LC_ALL, "");
-    bindtextdomain(GETTEXT_PACKAGE, GETTEXT_LOCALEDIR);
+    // Build the locale path from the APP_ID environment variable if this is a
+    // click package (this is the same logic as in LomiriI18n::setDomain() used
+    // in QML)
+    QString appDir = QString::fromLocal8Bit(getenv("APP_DIR"));
+    QString localePath = QStringLiteral(GETTEXT_LOCALEDIR);
+    if (QDir::isAbsolutePath (appDir)) {
+        localePath = QDir(appDir).filePath(QStringLiteral("share/locale"));
+    }
+    bindtextdomain(GETTEXT_PACKAGE, localePath.toUtf8());
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 
     // Load default city list into model when object is initiated
